NoCopy

Struct NoCopy 

#[repr(transparent)]
pub struct NoCopy<T: ?Sized>(pub T);
A simple packer, but no implement copy

This crate originates from the behavior of non move closures when capturing Copy types

Examples

let value;
{
    let n = 2;
    value = || n+1;
}
assert_eq!(value(), 3);

Imagine that it will compile? Actually, it won’t

For non move closures, if owned uses a copy types value, it will actually capture the reference

Use NoCopy to make n no longer a copy types, compile passed:

let value;
{
    let n = no_copy::NoCopy(2);
    value = || n+1;
}
assert_eq!(value(), 3);

Tuple Fields

0: T

Avoid use x.0 inside the closure, as the closure can capture fields

Trying *{x} or {x}.0?

Implementations

Source

impl<T: Copy> NoCopy<T>

pub const fn from_copy(value: T) -> Self

Only from can copy types.

Examples
use no_copy::NoCopy;

assert_eq!(NoCopy::from_copy(2), NoCopy(2));
use no_copy::NoCopy;

let non_copy = String::new();
let _ = NoCopy::from_copy(non_copy);
Source

impl<T: Copy> NoCopy<T>

pub const fn into_inner(this: Self) -> T